==> xkeycaps_2.29-3.tar.gz: xkeycaps-2.29/kbds/sun5swfr-caps.h <==
/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994
 * Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the Sun Swiss-French type 5 keyboard.
 * By Philippe A. Kipfer (Philippe.Kipfer@di.epfl.ch), dec.1993.
 * This keyboard meet the TUV standard.
 * Defined from Sun document "Notes claviers Sun type 5" ref. #800-6803-10
 *
 */

static struct key_strings sun5swfr_caps [] = {

  /* Row 0 */

  {"Help", 0},
  {"Esc", 0},
  {"F1", 0},
  {"F2", 0},
  {"F3", 0},
  {"F4", 0},
  {"F5", 0},
  {"F6", 0},
  {"F7", 0},
  {"F8", 0},
  {"F9", 0},
  {"F10", 0},
  {"F11", 0},
  {"F12", 0},
  {"Print", "Screen", 0},
  {"Scroll", "Lock", 0},
  {"Pause", 0},
  {"Degauss", "Mute", 0},
  {"Dim", "Quiet", 0},
  {"Bright", "Loud", 0},
  {"Power", 0},

  /* Row 1 */

  {"Stop", 0},
  {"Again", 0},
  {"0", "'", 0},
  {"+", "1", "|"},
  {"\"", "2", 0},
  {"*", "3", "#"},
  {"g", "4", "^"},
  {"%", "5", 0},
  {"&", "6", 0},
  {"/", "7", 0},
  {"(", "8", 0},
  {")", "9", 0},
  {"=", "0", "`"},
  {"?", "'", "'"},
  {"`", "^", "~"},

  {"Back", 0, 0},
  {"Insert", 0},
  {"Home", 0},
  {"Page", "Up", 0},
  {"Num", "Lock", 0},
  {"/", 0},
  {"*", 0},
  {"-", 0},

  /* Row 2 */

  {"Props", 0},
  {"Undo", 0},
  {"Tab", 0},
  {"Q", 0},
  {"W", 0},
  {"E", 0},
  {"R", 0},
  {"T", 0},
  {"Z", 0},
  {"U", 0},
  {"I", 0},
  {"O", 0},
  {"P", 0},
  {"|", "h", "["},
  {"!", "\"", "]"},

  {"Enter", 0},
  {"Del", 0},
  {"End", 0},
  {"Page", "Down", 0},
  {"7", "Home", 0},
  {"8", "upArrow", 0},
  {"9", "PgUp", 0},
  {"+", 0},

  /* Row 3 */

  {"Front", 0},
  {"Copy", 0},
  {"Caps Lock", 0},
  {"A", 0},
  {"S", 0},
  {"D", 0},
  {"F", 0},
  {"G", 0},
  {"H", 0},
  {"J", 0},
  {"K", 0},
  {"L", 0},
  {"v", "i", 0},
  {"d", "`", "{"},
  {"#", "$", "}"},

  {"4", "leftArrow", 0},
  {"5", 0},
  {"6", "rightArrow", 0},

  /* Row 4 */

  {"Open", 0},
  {"Paste", 0},
  {"Shift", 0},
  {">", "<", "\\"},
  {"Y", 0},
  {"X", 0},
  {"C", 0},
  {"V", 0},
  {"B", 0},
  {"N", 0},
  {"M", 0},
  {";", ",", 0},
  {":", ".", 0},
  {"_", "-", 0},
  {"Shift", 0},
  {"upArrow", 0},
  {"1", "End", 0},
  {"2", "downArrow", 0},
  {"3", "PgDn", 0},
  {"Enter", 0},

  /* Row 5 */

  {"Find", 0},
  {"Cut", 0},
  {"Control", 0},
  {"Alt", 0},
  {"<>", 0},
  {" ", 0},
  {"<>", 0},
  {"Com-", "pose", 0},
  {"Alt", "Graph", 0},
  {"leftArrow", 0},
  {"downArrow", 0},
  {"rightArrow", 0},
  {"0", "Ins", 0},
  {".", "Del", 0}
};

==> xkeycaps_2.42.orig.tar.gz: xkeycaps-2.42/kbds/sun5swfr-caps.h <==
/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1994
 * Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the Sun Swiss-French type 5 keyboard.
 * By Philippe A. Kipfer (Philippe.Kipfer@di.epfl.ch), dec.1993.
 * This keyboard meet the TUV standard.
 * Defined from Sun document "Notes claviers Sun type 5" ref. #800-6803-10
 *
 */

static const struct key_strings sun5swfr_caps [] = {

  /* Row 0 */

  {"Help", 0},
  {"Esc", 0},
  {"F1", 0},
  {"F2", 0},
  {"F3", 0},
  {"F4", 0},
  {"F5", 0},
  {"F6", 0},
  {"F7", 0},
  {"F8", 0},
  {"F9", 0},
  {"F10", 0},
  {"F11", 0},
  {"F12", 0},
  {"Print", "Screen", 0},
  {"Scroll", "Lock", 0},
  {"Pause", 0},
  {"Degauss", "Mute", 0},
  {"Dim", "Quiet", 0},
  {"Bright", "Loud", 0},
  {"Power", 0},

  /* Row 1 */

  {"Stop", 0},
  {"Again", 0},
  {"0", "'", 0},
  {"+", "1", "|"},
  {"\"", "2", 0},
  {"*", "3", "#"},
  {"g", "4", "^"},
  {"%", "5", 0},
  {"&", "6", 0},
  {"/", "7", 0},
  {"(", "8", 0},
  {")", "9", 0},
  {"=", "0", "`"},
  {"?", "'", "'"},
  {"`", "^", "~"},

  {"Back", 0, 0},
  {"Insert", 0},
  {"Home", 0},
  {"Page", "Up", 0},
  {"Num", "Lock", 0},
  {"/", 0},
  {"*", 0},
  {"-", 0},

  /* Row 2 */

  {"Props", 0},
  {"Undo", 0},
  {"Tab", 0},
  {"Q", 0},
  {"W", 0},
  {"E", 0},
  {"R", 0},
  {"T", 0},
  {"Z", 0},
  {"U", 0},
  {"I", 0},
  {"O", 0},
  {"P", 0},
  {"|", "h", "["},
  {"!", "\"", "]"},

  {"Enter", 0},
  {"Del", 0},
  {"End", 0},
  {"Page", "Down", 0},
  {"7", "Home", 0},
  {"8", "upArrow", 0},
  {"9", "PgUp", 0},
  {"+", 0},

  /* Row 3 */

  {"Front", 0},
  {"Copy", 0},
  {"Caps Lock", 0},
  {"A", 0},
  {"S", 0},
  {"D", 0},
  {"F", 0},
  {"G", 0},
  {"H", 0},
  {"J", 0},
  {"K", 0},
  {"L", 0},
  {"v", "i", 0},
  {"d", "`", "{"},
  {"#", "$", "}"},

  {"4", "leftArrow", 0},
  {"5", 0},
  {"6", "rightArrow", 0},

  /* Row 4 */

  {"Open", 0},
  {"Paste", 0},
  {"Shift", 0},
  {">", "<", "\\"},
  {"Y", 0},
  {"X", 0},
  {"C", 0},
  {"V", 0},
  {"B", 0},
  {"N", 0},
  {"M", 0},
  {";", ",", 0},
  {":", ".", 0},
  {"_", "-", 0},
  {"Shift", 0},
  {"upArrow", 0},
  {"1", "End", 0},
  {"2", "downArrow", 0},
  {"3", "PgDn", 0},
  {"Enter", 0},

  /* Row 5 */

  {"Find", 0},
  {"Cut", 0},
  {"Control", 0},
  {"Alt", 0},
  {"<>", 0},
  {" ", 0},
  {"<>", 0},
  {"Com-", "pose", 0},
  {"Alt", "Graph", 0},
  {"leftArrow", 0},
  {"downArrow", 0},
  {"rightArrow", 0},
  {"0", "Ins", 0},
  {".", "Del", 0}
};
